@@ -39,9 +39,10 @@ class PSF(Effect):
                     obj.view(self.meta["sub_pixel_flag"])
                 old_shape = obj.hdu.data.shape
 
-                kernel = self.get_kernel(obj)
                 mode = self.meta["convolve_mode"]
-                new_image = convolve(obj.hdu.data, kernel, mode=mode)
+                kernel = self.get_kernel(obj).astype(float)
+                image = obj.hdu.data.astype(float)
+                new_image = convolve(image, kernel, mode=mode)
                 new_shape = new_image.shape
 
                 obj.hdu.data = new_image
@@ -107,7 +108,7 @@ class Vibration(AnalyticalPSF):
             self.kernel = Gaussian2DKernel(sigma, x_size=width, y_size=width,
                                            mode="center").array
 
-        return self.kernel
+        return self.kernel.astype(float)
 
 
 class NonCommonPathAberration(AnalyticalPSF):
@@ -174,10 +175,41 @@ class NonCommonPathAberration(AnalyticalPSF):
         return self._total_wfe
 
 
-class Seeing(AnalyticalPSF):
-    def __init__(self, **kwargs):
-        super(Seeing, self).__init__(**kwargs)
-        self.meta["z_order"] = [243, 643]
+class SeeingPSF(AnalyticalPSF):
+    """
+    Currently only returns gaussian kernel with a ``fwhm`` [arcsec]
+    """
+    def __init__(self, fwhm=1.5, **kwargs):
+        super(SeeingPSF, self).__init__(**kwargs)
+        self.meta["fwhm"] = fwhm
+        self.meta["z_order"] = [242, 642]
+
+    def fov_grid(self, which="waveset", **kwargs):
+        wavelengths = []
+        if which == "waveset" and \
+                "waverange" in kwargs and \
+                "pixel_scale" in kwargs:
+            waverange = utils.quantify(kwargs["waverange"], u.um)
+            wavelengths = waverange
+            # ..todo: return something useful
+
+        # .. todo: check that this is actually correct
+        return wavelengths
+
+    def get_kernel(self, fov):
+        # called by .apply_to() from the base PSF class
+
+        pixel_scale = fov.header["CDELT1"] * u.deg.to(u.arcsec)
+        pixel_scale = utils.quantify(pixel_scale, u.arcsec)
+        wave = fov.wavelength
+
+        ### add in the conversion to fwhm from seeing and wavelength here
+        fwhm = self.meta["fwhm"] * u.arcsec / pixel_scale
+
+        sigma = fwhm.value / 2.35
+        kernel = Gaussian2DKernel(sigma, mode="center").array
+
+        return kernel
 
 
 class GaussianDiffractionPSF(AnalyticalPSF):
@@ -352,7 +384,9 @@ class FieldVaryingPSF(DiscretePSF):
                     kernel /= sum_kernel
 
                 # image convolution
-                new_image = convolve(fov.hdu.data, kernel, mode="same")
+                image = fov.hdu.data.astype(float)
+                kernel = kernel.astype(float)
+                new_image = convolve(image, kernel, mode="same")
                 if canvas is None:
                     canvas = np.zeros(new_image.shape)
 
